@@ -1361,6 +1361,11 @@ function getStatusColorJS(status) {
 }
 
 function formatBytesJS(bytes, precision = 2) {
+    // Handle null, undefined, or invalid values
+    if (bytes === null || bytes === undefined || isNaN(bytes) || bytes < 0) {
+        return '0 B';
+    }
+    
     const units = ['B', 'KB', 'MB', 'GB', 'TB'];
     
     for (let i = 0; bytes > 1024 && i < units.length - 1; i++) {
